@@ -15,6 +15,14 @@ from ..Functions.load import load_init_dict
 from ..Functions.Load.import_class import import_class
 from ._frozen import FrozenClass
 
+# Import all class method
+# Try/catch to remove unnecessary dependencies in unused method
+try:
+    from ..Methods.Simulation.DataKeeper.as_dict import as_dict
+except ImportError as error:
+    as_dict = error
+
+
 from ntpath import basename
 from os.path import isfile
 from ._check import CheckTypeError
@@ -28,6 +36,15 @@ class DataKeeper(FrozenClass):
 
     VERSION = 1
 
+    # cf Methods.Simulation.DataKeeper.as_dict
+    if isinstance(as_dict, ImportError):
+        as_dict = property(
+            fget=lambda x: raise_(
+                ImportError("Can't use DataKeeper method as_dict: " + str(as_dict))
+            )
+        )
+    else:
+        as_dict = as_dict
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -42,6 +59,7 @@ class DataKeeper(FrozenClass):
         keeper=None,
         error_keeper=None,
         result=-1,
+        result_ref=None,
         init_dict=None,
         init_str=None,
     ):
@@ -72,6 +90,8 @@ class DataKeeper(FrozenClass):
                 error_keeper = init_dict["error_keeper"]
             if "result" in list(init_dict.keys()):
                 result = init_dict["result"]
+            if "result_ref" in list(init_dict.keys()):
+                result_ref = init_dict["result_ref"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.name = name
@@ -80,6 +100,7 @@ class DataKeeper(FrozenClass):
         self.keeper = keeper
         self.error_keeper = error_keeper
         self.result = result
+        self.result_ref = result_ref
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -113,6 +134,7 @@ class DataKeeper(FrozenClass):
             + str(self.result).replace(linesep, linesep + "\t")
             + linesep
         )
+        DataKeeper_str += "result_ref = " + str(self.result_ref) + linesep + linesep
         return DataKeeper_str
 
     def __eq__(self, other):
@@ -132,8 +154,50 @@ class DataKeeper(FrozenClass):
             return False
         if other.result != self.result:
             return False
+        if isinstance(self.result_ref, np.ndarray) and not np.array_equal(
+            other.result_ref, self.result_ref
+        ):
+            return False
+        elif other.result_ref != self.result_ref:
+            return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+        if other._name != self._name:
+            diff_list.append(name + ".name")
+        if other._symbol != self._symbol:
+            diff_list.append(name + ".symbol")
+        if other._unit != self._unit:
+            diff_list.append(name + ".unit")
+        if other._keeper_str != self._keeper_str:
+            diff_list.append(name + ".keeper")
+        if other._error_keeper_str != self._error_keeper_str:
+            diff_list.append(name + ".error_keeper")
+        if other._result != self._result:
+            diff_list.append(name + ".result")
+        if (other.result_ref is None and self.result_ref is not None) or (
+            other.result_ref is not None and self.result_ref is None
+        ):
+            diff_list.append(name + ".result_ref")
+        elif self.result_ref is None:
+            pass
+        elif isinstance(self.result_ref, np.ndarray) and not np.array_equal(
+            other.result_ref, self.result_ref
+        ):
+            diff_list.append(name + ".result_ref")
+        elif hasattr(self.result_ref, "compare"):
+            diff_list.extend(
+                self.result_ref.compare(other.result_ref, name=name + ".result_ref")
+            )
+        elif other._result_ref != self._result_ref:
+            diff_list.append(name + ".result_ref")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -146,30 +210,9 @@ class DataKeeper(FrozenClass):
         if self.result is not None:
             for value in self.result:
                 S += getsizeof(value)
+        S += getsizeof(self.result_ref)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
-
-        DataKeeper_dict = dict()
-        DataKeeper_dict["name"] = self.name
-        DataKeeper_dict["symbol"] = self.symbol
-        DataKeeper_dict["unit"] = self.unit
-        if self._keeper_str is not None:
-            DataKeeper_dict["keeper"] = self._keeper_str
-        else:
-            DataKeeper_dict["keeper"] = None
-        if self._error_keeper_str is not None:
-            DataKeeper_dict["error_keeper"] = self._error_keeper_str
-        else:
-            DataKeeper_dict["error_keeper"] = None
-        DataKeeper_dict["result"] = (
-            self.result.copy() if self.result is not None else None
-        )
-        # The class name is added to the dict for deserialisation purpose
-        DataKeeper_dict["__class__"] = "DataKeeper"
-        return DataKeeper_dict
-
     def _set_None(self):
         """Set all the properties to None (except pyleecan object)"""
 
@@ -179,6 +222,10 @@ class DataKeeper(FrozenClass):
         self.keeper = None
         self.error_keeper = None
         self.result = None
+        if hasattr(self.result_ref, "_set_None"):
+            self.result_ref._set_None()
+        else:
+            self.result_ref = None
 
     def _get_name(self):
         """getter of name"""
@@ -323,3 +370,39 @@ class DataKeeper(FrozenClass):
         :Type: list
         """,
     )
+
+    def _get_result_ref(self):
+        """getter of result_ref"""
+        return self._result_ref
+
+    def _set_result_ref(self, value):
+        """setter of result_ref"""
+        if isinstance(value, dict) and "__class__" in value:
+            try:
+                class_obj = import_class(
+                    "pyleecan.Classes", value.get("__class__"), "result_ref"
+                )
+            except:
+                class_obj = import_class(
+                    "SciDataTool.Classes", value.get("__class__"), "result_ref"
+                )
+            value = class_obj(init_dict=value)
+        elif type(value) is list:
+            try:
+                value = np.array(value)
+            except:
+                pass
+        check_var("result_ref", value, "")
+        self._result_ref = value
+
+        if hasattr(self._result_ref, "parent"):
+            self._result_ref.parent = self
+
+    result_ref = property(
+        fget=_get_result_ref,
+        fset=_set_result_ref,
+        doc=u"""Result for the reference simulation
+
+        :Type: 
+        """,
+    )
