@@ -96,6 +96,19 @@ class FPGNSeg(GaussPoint):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from GaussPoint
+        diff_list.extend(super(FPGNSeg, self).compare(other, name=name))
+        if other._nb_gauss_point != self._nb_gauss_point:
+            diff_list.append(name + ".nb_gauss_point")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -106,11 +119,15 @@ class FPGNSeg(GaussPoint):
         S += getsizeof(self.nb_gauss_point)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from GaussPoint
-        FPGNSeg_dict = super(FPGNSeg, self).as_dict()
+        FPGNSeg_dict = super(FPGNSeg, self).as_dict(**kwargs)
         FPGNSeg_dict["nb_gauss_point"] = self.nb_gauss_point
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
