@@ -37,11 +37,21 @@ try:
 except ImportError as error:
     comp_alpha = error
 
+try:
+    from ..Methods.Slot.HoleM50.comp_magnetization_dict import comp_magnetization_dict
+except ImportError as error:
+    comp_magnetization_dict = error
+
 try:
     from ..Methods.Slot.HoleM50.comp_radius import comp_radius
 except ImportError as error:
     comp_radius = error
 
+try:
+    from ..Methods.Slot.HoleM50.comp_surface_magnet_id import comp_surface_magnet_id
+except ImportError as error:
+    comp_surface_magnet_id = error
+
 try:
     from ..Methods.Slot.HoleM50.comp_W5 import comp_W5
 except ImportError as error:
@@ -52,21 +62,16 @@ try:
 except ImportError as error:
     has_magnet = error
 
-try:
-    from ..Methods.Slot.HoleM50.remove_magnet import remove_magnet
-except ImportError as error:
-    remove_magnet = error
-
-try:
-    from ..Methods.Slot.HoleM50.comp_surface_magnet_id import comp_surface_magnet_id
-except ImportError as error:
-    comp_surface_magnet_id = error
-
 try:
     from ..Methods.Slot.HoleM50.plot_schematics import plot_schematics
 except ImportError as error:
     plot_schematics = error
 
+try:
+    from ..Methods.Slot.HoleM50.remove_magnet import remove_magnet
+except ImportError as error:
+    remove_magnet = error
+
 
 from ._check import InitUnKnowClassError
 from .Magnet import Magnet
@@ -121,6 +126,18 @@ class HoleM50(HoleMag):
         )
     else:
         comp_alpha = comp_alpha
+    # cf Methods.Slot.HoleM50.comp_magnetization_dict
+    if isinstance(comp_magnetization_dict, ImportError):
+        comp_magnetization_dict = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM50 method comp_magnetization_dict: "
+                    + str(comp_magnetization_dict)
+                )
+            )
+        )
+    else:
+        comp_magnetization_dict = comp_magnetization_dict
     # cf Methods.Slot.HoleM50.comp_radius
     if isinstance(comp_radius, ImportError):
         comp_radius = property(
@@ -130,6 +147,18 @@ class HoleM50(HoleMag):
         )
     else:
         comp_radius = comp_radius
+    # cf Methods.Slot.HoleM50.comp_surface_magnet_id
+    if isinstance(comp_surface_magnet_id, ImportError):
+        comp_surface_magnet_id = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM50 method comp_surface_magnet_id: "
+                    + str(comp_surface_magnet_id)
+                )
+            )
+        )
+    else:
+        comp_surface_magnet_id = comp_surface_magnet_id
     # cf Methods.Slot.HoleM50.comp_W5
     if isinstance(comp_W5, ImportError):
         comp_W5 = property(
@@ -148,29 +177,6 @@ class HoleM50(HoleMag):
         )
     else:
         has_magnet = has_magnet
-    # cf Methods.Slot.HoleM50.remove_magnet
-    if isinstance(remove_magnet, ImportError):
-        remove_magnet = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use HoleM50 method remove_magnet: " + str(remove_magnet)
-                )
-            )
-        )
-    else:
-        remove_magnet = remove_magnet
-    # cf Methods.Slot.HoleM50.comp_surface_magnet_id
-    if isinstance(comp_surface_magnet_id, ImportError):
-        comp_surface_magnet_id = property(
-            fget=lambda x: raise_(
-                ImportError(
-                    "Can't use HoleM50 method comp_surface_magnet_id: "
-                    + str(comp_surface_magnet_id)
-                )
-            )
-        )
-    else:
-        comp_surface_magnet_id = comp_surface_magnet_id
     # cf Methods.Slot.HoleM50.plot_schematics
     if isinstance(plot_schematics, ImportError):
         plot_schematics = property(
@@ -182,6 +188,17 @@ class HoleM50(HoleMag):
         )
     else:
         plot_schematics = plot_schematics
+    # cf Methods.Slot.HoleM50.remove_magnet
+    if isinstance(remove_magnet, ImportError):
+        remove_magnet = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM50 method remove_magnet: " + str(remove_magnet)
+                )
+            )
+        )
+    else:
+        remove_magnet = remove_magnet
     # save and copy methods are available in all object
     save = save
     copy = copy
@@ -204,6 +221,7 @@ class HoleM50(HoleMag):
         magnet_1=-1,
         Zh=36,
         mat_void=-1,
+        magnetization_dict_offset=None,
         init_dict=None,
         init_str=None,
     ):
@@ -250,6 +268,8 @@ class HoleM50(HoleMag):
                 Zh = init_dict["Zh"]
             if "mat_void" in list(init_dict.keys()):
                 mat_void = init_dict["mat_void"]
+            if "magnetization_dict_offset" in list(init_dict.keys()):
+                magnetization_dict_offset = init_dict["magnetization_dict_offset"]
         # Set the properties (value check and convertion are done in setter)
         self.H0 = H0
         self.W0 = W0
@@ -264,7 +284,11 @@ class HoleM50(HoleMag):
         self.magnet_0 = magnet_0
         self.magnet_1 = magnet_1
         # Call HoleMag init
-        super(HoleM50, self).__init__(Zh=Zh, mat_void=mat_void)
+        super(HoleM50, self).__init__(
+            Zh=Zh,
+            mat_void=mat_void,
+            magnetization_dict_offset=magnetization_dict_offset,
+        )
         # The class is frozen (in HoleMag init), for now it's impossible to
         # add new properties
 
@@ -331,6 +355,53 @@ class HoleM50(HoleMag):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from HoleMag
+        diff_list.extend(super(HoleM50, self).compare(other, name=name))
+        if other._H0 != self._H0:
+            diff_list.append(name + ".H0")
+        if other._W0 != self._W0:
+            diff_list.append(name + ".W0")
+        if other._H1 != self._H1:
+            diff_list.append(name + ".H1")
+        if other._W1 != self._W1:
+            diff_list.append(name + ".W1")
+        if other._H2 != self._H2:
+            diff_list.append(name + ".H2")
+        if other._W2 != self._W2:
+            diff_list.append(name + ".W2")
+        if other._H3 != self._H3:
+            diff_list.append(name + ".H3")
+        if other._W3 != self._W3:
+            diff_list.append(name + ".W3")
+        if other._H4 != self._H4:
+            diff_list.append(name + ".H4")
+        if other._W4 != self._W4:
+            diff_list.append(name + ".W4")
+        if (other.magnet_0 is None and self.magnet_0 is not None) or (
+            other.magnet_0 is not None and self.magnet_0 is None
+        ):
+            diff_list.append(name + ".magnet_0 None mismatch")
+        elif self.magnet_0 is not None:
+            diff_list.extend(
+                self.magnet_0.compare(other.magnet_0, name=name + ".magnet_0")
+            )
+        if (other.magnet_1 is None and self.magnet_1 is not None) or (
+            other.magnet_1 is not None and self.magnet_1 is None
+        ):
+            diff_list.append(name + ".magnet_1 None mismatch")
+        elif self.magnet_1 is not None:
+            diff_list.extend(
+                self.magnet_1.compare(other.magnet_1, name=name + ".magnet_1")
+            )
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -352,11 +423,15 @@ class HoleM50(HoleMag):
         S += getsizeof(self.magnet_1)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from HoleMag
-        HoleM50_dict = super(HoleM50, self).as_dict()
+        HoleM50_dict = super(HoleM50, self).as_dict(**kwargs)
         HoleM50_dict["H0"] = self.H0
         HoleM50_dict["W0"] = self.W0
         HoleM50_dict["H1"] = self.H1
@@ -370,11 +445,11 @@ class HoleM50(HoleMag):
         if self.magnet_0 is None:
             HoleM50_dict["magnet_0"] = None
         else:
-            HoleM50_dict["magnet_0"] = self.magnet_0.as_dict()
+            HoleM50_dict["magnet_0"] = self.magnet_0.as_dict(**kwargs)
         if self.magnet_1 is None:
             HoleM50_dict["magnet_1"] = None
         else:
-            HoleM50_dict["magnet_1"] = self.magnet_1.as_dict()
+            HoleM50_dict["magnet_1"] = self.magnet_1.as_dict(**kwargs)
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         HoleM50_dict["__class__"] = "HoleM50"
