@@ -37,6 +37,11 @@ try:
 except ImportError as error:
     comp_alpha = error
 
+try:
+    from ..Methods.Slot.HoleM51.comp_magnetization_dict import comp_magnetization_dict
+except ImportError as error:
+    comp_magnetization_dict = error
+
 try:
     from ..Methods.Slot.HoleM51.comp_radius import comp_radius
 except ImportError as error:
@@ -121,6 +126,18 @@ class HoleM51(HoleMag):
         )
     else:
         comp_alpha = comp_alpha
+    # cf Methods.Slot.HoleM51.comp_magnetization_dict
+    if isinstance(comp_magnetization_dict, ImportError):
+        comp_magnetization_dict = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM51 method comp_magnetization_dict: "
+                    + str(comp_magnetization_dict)
+                )
+            )
+        )
+    else:
+        comp_magnetization_dict = comp_magnetization_dict
     # cf Methods.Slot.HoleM51.comp_radius
     if isinstance(comp_radius, ImportError):
         comp_radius = property(
@@ -206,6 +223,7 @@ class HoleM51(HoleMag):
         magnet_2=-1,
         Zh=36,
         mat_void=-1,
+        magnetization_dict_offset=None,
         init_dict=None,
         init_str=None,
     ):
@@ -256,6 +274,8 @@ class HoleM51(HoleMag):
                 Zh = init_dict["Zh"]
             if "mat_void" in list(init_dict.keys()):
                 mat_void = init_dict["mat_void"]
+            if "magnetization_dict_offset" in list(init_dict.keys()):
+                magnetization_dict_offset = init_dict["magnetization_dict_offset"]
         # Set the properties (value check and convertion are done in setter)
         self.H0 = H0
         self.H1 = H1
@@ -272,7 +292,11 @@ class HoleM51(HoleMag):
         self.magnet_1 = magnet_1
         self.magnet_2 = magnet_2
         # Call HoleMag init
-        super(HoleM51, self).__init__(Zh=Zh, mat_void=mat_void)
+        super(HoleM51, self).__init__(
+            Zh=Zh,
+            mat_void=mat_void,
+            magnetization_dict_offset=magnetization_dict_offset,
+        )
         # The class is frozen (in HoleMag init), for now it's impossible to
         # add new properties
 
@@ -349,6 +373,63 @@ class HoleM51(HoleMag):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from HoleMag
+        diff_list.extend(super(HoleM51, self).compare(other, name=name))
+        if other._H0 != self._H0:
+            diff_list.append(name + ".H0")
+        if other._H1 != self._H1:
+            diff_list.append(name + ".H1")
+        if other._H2 != self._H2:
+            diff_list.append(name + ".H2")
+        if other._W0 != self._W0:
+            diff_list.append(name + ".W0")
+        if other._W1 != self._W1:
+            diff_list.append(name + ".W1")
+        if other._W2 != self._W2:
+            diff_list.append(name + ".W2")
+        if other._W3 != self._W3:
+            diff_list.append(name + ".W3")
+        if other._W4 != self._W4:
+            diff_list.append(name + ".W4")
+        if other._W5 != self._W5:
+            diff_list.append(name + ".W5")
+        if other._W6 != self._W6:
+            diff_list.append(name + ".W6")
+        if other._W7 != self._W7:
+            diff_list.append(name + ".W7")
+        if (other.magnet_0 is None and self.magnet_0 is not None) or (
+            other.magnet_0 is not None and self.magnet_0 is None
+        ):
+            diff_list.append(name + ".magnet_0 None mismatch")
+        elif self.magnet_0 is not None:
+            diff_list.extend(
+                self.magnet_0.compare(other.magnet_0, name=name + ".magnet_0")
+            )
+        if (other.magnet_1 is None and self.magnet_1 is not None) or (
+            other.magnet_1 is not None and self.magnet_1 is None
+        ):
+            diff_list.append(name + ".magnet_1 None mismatch")
+        elif self.magnet_1 is not None:
+            diff_list.extend(
+                self.magnet_1.compare(other.magnet_1, name=name + ".magnet_1")
+            )
+        if (other.magnet_2 is None and self.magnet_2 is not None) or (
+            other.magnet_2 is not None and self.magnet_2 is None
+        ):
+            diff_list.append(name + ".magnet_2 None mismatch")
+        elif self.magnet_2 is not None:
+            diff_list.extend(
+                self.magnet_2.compare(other.magnet_2, name=name + ".magnet_2")
+            )
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -372,11 +453,15 @@ class HoleM51(HoleMag):
         S += getsizeof(self.magnet_2)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from HoleMag
-        HoleM51_dict = super(HoleM51, self).as_dict()
+        HoleM51_dict = super(HoleM51, self).as_dict(**kwargs)
         HoleM51_dict["H0"] = self.H0
         HoleM51_dict["H1"] = self.H1
         HoleM51_dict["H2"] = self.H2
@@ -391,15 +476,15 @@ class HoleM51(HoleMag):
         if self.magnet_0 is None:
             HoleM51_dict["magnet_0"] = None
         else:
-            HoleM51_dict["magnet_0"] = self.magnet_0.as_dict()
+            HoleM51_dict["magnet_0"] = self.magnet_0.as_dict(**kwargs)
         if self.magnet_1 is None:
             HoleM51_dict["magnet_1"] = None
         else:
-            HoleM51_dict["magnet_1"] = self.magnet_1.as_dict()
+            HoleM51_dict["magnet_1"] = self.magnet_1.as_dict(**kwargs)
         if self.magnet_2 is None:
             HoleM51_dict["magnet_2"] = None
         else:
-            HoleM51_dict["magnet_2"] = self.magnet_2.as_dict()
+            HoleM51_dict["magnet_2"] = self.magnet_2.as_dict(**kwargs)
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         HoleM51_dict["__class__"] = "HoleM51"
