@@ -32,6 +32,11 @@ try:
 except ImportError as error:
     check = error
 
+try:
+    from ..Methods.Slot.HoleM54.comp_magnetization_dict import comp_magnetization_dict
+except ImportError as error:
+    comp_magnetization_dict = error
+
 try:
     from ..Methods.Slot.HoleM54.comp_radius import comp_radius
 except ImportError as error:
@@ -91,6 +96,18 @@ class HoleM54(Hole):
         )
     else:
         check = check
+    # cf Methods.Slot.HoleM54.comp_magnetization_dict
+    if isinstance(comp_magnetization_dict, ImportError):
+        comp_magnetization_dict = property(
+            fget=lambda x: raise_(
+                ImportError(
+                    "Can't use HoleM54 method comp_magnetization_dict: "
+                    + str(comp_magnetization_dict)
+                )
+            )
+        )
+    else:
+        comp_magnetization_dict = comp_magnetization_dict
     # cf Methods.Slot.HoleM54.comp_radius
     if isinstance(comp_radius, ImportError):
         comp_radius = property(
@@ -136,6 +153,7 @@ class HoleM54(Hole):
         R1=0.02,
         Zh=36,
         mat_void=-1,
+        magnetization_dict_offset=None,
         init_dict=None,
         init_str=None,
     ):
@@ -166,13 +184,19 @@ class HoleM54(Hole):
                 Zh = init_dict["Zh"]
             if "mat_void" in list(init_dict.keys()):
                 mat_void = init_dict["mat_void"]
+            if "magnetization_dict_offset" in list(init_dict.keys()):
+                magnetization_dict_offset = init_dict["magnetization_dict_offset"]
         # Set the properties (value check and convertion are done in setter)
         self.H0 = H0
         self.H1 = H1
         self.W0 = W0
         self.R1 = R1
         # Call Hole init
-        super(HoleM54, self).__init__(Zh=Zh, mat_void=mat_void)
+        super(HoleM54, self).__init__(
+            Zh=Zh,
+            mat_void=mat_void,
+            magnetization_dict_offset=magnetization_dict_offset,
+        )
         # The class is frozen (in Hole init), for now it's impossible to
         # add new properties
 
@@ -207,6 +231,25 @@ class HoleM54(Hole):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from Hole
+        diff_list.extend(super(HoleM54, self).compare(other, name=name))
+        if other._H0 != self._H0:
+            diff_list.append(name + ".H0")
+        if other._H1 != self._H1:
+            diff_list.append(name + ".H1")
+        if other._W0 != self._W0:
+            diff_list.append(name + ".W0")
+        if other._R1 != self._R1:
+            diff_list.append(name + ".R1")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -220,11 +263,15 @@ class HoleM54(Hole):
         S += getsizeof(self.R1)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from Hole
-        HoleM54_dict = super(HoleM54, self).as_dict()
+        HoleM54_dict = super(HoleM54, self).as_dict(**kwargs)
         HoleM54_dict["H0"] = self.H0
         HoleM54_dict["H1"] = self.H1
         HoleM54_dict["W0"] = self.W0
