@@ -299,6 +299,29 @@ class LamSquirrelCage(LamSlotWind):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from LamSlotWind
+        diff_list.extend(super(LamSquirrelCage, self).compare(other, name=name))
+        if other._Hscr != self._Hscr:
+            diff_list.append(name + ".Hscr")
+        if other._Lscr != self._Lscr:
+            diff_list.append(name + ".Lscr")
+        if (other.ring_mat is None and self.ring_mat is not None) or (
+            other.ring_mat is not None and self.ring_mat is None
+        ):
+            diff_list.append(name + ".ring_mat None mismatch")
+        elif self.ring_mat is not None:
+            diff_list.extend(
+                self.ring_mat.compare(other.ring_mat, name=name + ".ring_mat")
+            )
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -311,17 +334,21 @@ class LamSquirrelCage(LamSlotWind):
         S += getsizeof(self.ring_mat)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from LamSlotWind
-        LamSquirrelCage_dict = super(LamSquirrelCage, self).as_dict()
+        LamSquirrelCage_dict = super(LamSquirrelCage, self).as_dict(**kwargs)
         LamSquirrelCage_dict["Hscr"] = self.Hscr
         LamSquirrelCage_dict["Lscr"] = self.Lscr
         if self.ring_mat is None:
             LamSquirrelCage_dict["ring_mat"] = None
         else:
-            LamSquirrelCage_dict["ring_mat"] = self.ring_mat.as_dict()
+            LamSquirrelCage_dict["ring_mat"] = self.ring_mat.as_dict(**kwargs)
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         LamSquirrelCage_dict["__class__"] = "LamSquirrelCage"
