@@ -184,12 +184,13 @@ class MeshSolution(FrozenClass):
 
     def __init__(
         self,
-        label=None,
+        label="",
         mesh=-1,
         is_same_mesh=True,
         solution=-1,
         group=None,
         dimension=2,
+        path=None,
         init_dict=None,
         init_str=None,
     ):
@@ -220,6 +221,8 @@ class MeshSolution(FrozenClass):
                 group = init_dict["group"]
             if "dimension" in list(init_dict.keys()):
                 dimension = init_dict["dimension"]
+            if "path" in list(init_dict.keys()):
+                path = init_dict["path"]
         # Set the properties (value check and convertion are done in setter)
         self.parent = None
         self.label = label
@@ -228,6 +231,7 @@ class MeshSolution(FrozenClass):
         self.solution = solution
         self.group = group
         self.dimension = dimension
+        self.path = path
 
         # The class is frozen, for now it's impossible to add new properties
         self._freeze()
@@ -261,6 +265,7 @@ class MeshSolution(FrozenClass):
                 "group[" + key + "] = " + str(self.group[key]) + linesep + linesep
             )
         MeshSolution_str += "dimension = " + str(self.dimension) + linesep
+        MeshSolution_str += 'path = "' + str(self.path) + '"' + linesep
         return MeshSolution_str
 
     def __eq__(self, other):
@@ -281,7 +286,7 @@ class MeshSolution(FrozenClass):
         ):
             return False
         elif other.group is None and self.group is None:
-            return True
+            pass
         elif len(other.group) != len(self.group):
             return False
         else:
@@ -292,8 +297,70 @@ class MeshSolution(FrozenClass):
                     return False
         if other.dimension != self.dimension:
             return False
+        if other.path != self.path:
+            return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+        if other._label != self._label:
+            diff_list.append(name + ".label")
+        if (other.mesh is None and self.mesh is not None) or (
+            other.mesh is not None and self.mesh is None
+        ):
+            diff_list.append(name + ".mesh None mismatch")
+        elif self.mesh is None:
+            pass
+        elif len(other.mesh) != len(self.mesh):
+            diff_list.append("len(" + name + ".mesh)")
+        else:
+            for ii in range(len(other.mesh)):
+                diff_list.extend(
+                    self.mesh[ii].compare(
+                        other.mesh[ii], name=name + ".mesh[" + str(ii) + "]"
+                    )
+                )
+        if other._is_same_mesh != self._is_same_mesh:
+            diff_list.append(name + ".is_same_mesh")
+        if (other.solution is None and self.solution is not None) or (
+            other.solution is not None and self.solution is None
+        ):
+            diff_list.append(name + ".solution None mismatch")
+        elif self.solution is None:
+            pass
+        elif len(other.solution) != len(self.solution):
+            diff_list.append("len(" + name + ".solution)")
+        else:
+            for ii in range(len(other.solution)):
+                diff_list.extend(
+                    self.solution[ii].compare(
+                        other.solution[ii], name=name + ".solution[" + str(ii) + "]"
+                    )
+                )
+        if (other.group is None and self.group is not None) or (
+            other.group is not None and self.group is None
+        ):
+            diff_list.append(name + ".group None mismatch")
+        elif self.group is None:
+            pass
+        elif len(other.group) != len(self.group):
+            diff_list.append("len(" + name + ".group)")
+        else:
+            for key in other.group:
+                if key not in self.group or not array_equal(
+                    other.group[key], self.group[key]
+                ):
+                    diff_list.append(name + ".group[" + str(key) + "]")
+        if other._dimension != self._dimension:
+            diff_list.append(name + ".dimension")
+        if other._path != self._path:
+            diff_list.append(name + ".path")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -310,10 +377,15 @@ class MeshSolution(FrozenClass):
             for key, value in self.group.items():
                 S += getsizeof(value) + getsizeof(key)
         S += getsizeof(self.dimension)
+        S += getsizeof(self.path)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         MeshSolution_dict = dict()
         MeshSolution_dict["label"] = self.label
@@ -323,7 +395,7 @@ class MeshSolution(FrozenClass):
             MeshSolution_dict["mesh"] = list()
             for obj in self.mesh:
                 if obj is not None:
-                    MeshSolution_dict["mesh"].append(obj.as_dict())
+                    MeshSolution_dict["mesh"].append(obj.as_dict(**kwargs))
                 else:
                     MeshSolution_dict["mesh"].append(None)
         MeshSolution_dict["is_same_mesh"] = self.is_same_mesh
@@ -333,7 +405,7 @@ class MeshSolution(FrozenClass):
             MeshSolution_dict["solution"] = list()
             for obj in self.solution:
                 if obj is not None:
-                    MeshSolution_dict["solution"].append(obj.as_dict())
+                    MeshSolution_dict["solution"].append(obj.as_dict(**kwargs))
                 else:
                     MeshSolution_dict["solution"].append(None)
         if self.group is None:
@@ -343,6 +415,7 @@ class MeshSolution(FrozenClass):
             for key, obj in self.group.items():
                 MeshSolution_dict["group"][key] = obj.tolist()
         MeshSolution_dict["dimension"] = self.dimension
+        MeshSolution_dict["path"] = self.path
         # The class name is added to the dict for deserialisation purpose
         MeshSolution_dict["__class__"] = "MeshSolution"
         return MeshSolution_dict
@@ -356,6 +429,7 @@ class MeshSolution(FrozenClass):
         self.solution = None
         self.group = None
         self.dimension = None
+        self.path = None
 
     def _get_label(self):
         """getter of label"""
@@ -505,3 +579,21 @@ class MeshSolution(FrozenClass):
         :max: 3
         """,
     )
+
+    def _get_path(self):
+        """getter of path"""
+        return self._path
+
+    def _set_path(self, value):
+        """setter of path"""
+        check_var("path", value, "str")
+        self._path = value
+
+    path = property(
+        fget=_get_path,
+        fset=_set_path,
+        doc=u"""Path where the MeshSolution is stored as a file
+
+        :Type: str
+        """,
+    )
