@@ -241,6 +241,25 @@ class OptiGenAlgNsga2Deap(OptiGenAlg):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from OptiGenAlg
+        diff_list.extend(super(OptiGenAlgNsga2Deap, self).compare(other, name=name))
+        if (other.toolbox is None and self.toolbox is not None) or (
+            other.toolbox is not None and self.toolbox is None
+        ):
+            diff_list.append(name + ".toolbox None mismatch")
+        elif self.toolbox is not None:
+            diff_list.extend(
+                self.toolbox.compare(other.toolbox, name=name + ".toolbox")
+            )
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -251,14 +270,20 @@ class OptiGenAlgNsga2Deap(OptiGenAlg):
         S += getsizeof(self.toolbox)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from OptiGenAlg
-        OptiGenAlgNsga2Deap_dict = super(OptiGenAlgNsga2Deap, self).as_dict()
+        OptiGenAlgNsga2Deap_dict = super(OptiGenAlgNsga2Deap, self).as_dict(**kwargs)
         if self.toolbox is None:
             OptiGenAlgNsga2Deap_dict["toolbox"] = None
-        else:  # Store serialized data (using cloudpickle) and str to read it in json save files
+        else:
+            # Store serialized data (using cloudpickle) and str
+            # to read it in json save files
             OptiGenAlgNsga2Deap_dict["toolbox"] = {
                 "__class__": str(type(self._toolbox)),
                 "__repr__": str(self._toolbox.__repr__()),
