@@ -174,6 +174,85 @@ class OptiProblem(FrozenClass):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+        if (other.simu is None and self.simu is not None) or (
+            other.simu is not None and self.simu is None
+        ):
+            diff_list.append(name + ".simu None mismatch")
+        elif self.simu is not None:
+            diff_list.extend(self.simu.compare(other.simu, name=name + ".simu"))
+        if (other.design_var is None and self.design_var is not None) or (
+            other.design_var is not None and self.design_var is None
+        ):
+            diff_list.append(name + ".design_var None mismatch")
+        elif self.design_var is None:
+            pass
+        elif len(other.design_var) != len(self.design_var):
+            diff_list.append("len(" + name + ".design_var)")
+        else:
+            for ii in range(len(other.design_var)):
+                diff_list.extend(
+                    self.design_var[ii].compare(
+                        other.design_var[ii], name=name + ".design_var[" + str(ii) + "]"
+                    )
+                )
+        if (other.obj_func is None and self.obj_func is not None) or (
+            other.obj_func is not None and self.obj_func is None
+        ):
+            diff_list.append(name + ".obj_func None mismatch")
+        elif self.obj_func is None:
+            pass
+        elif len(other.obj_func) != len(self.obj_func):
+            diff_list.append("len(" + name + ".obj_func)")
+        else:
+            for ii in range(len(other.obj_func)):
+                diff_list.extend(
+                    self.obj_func[ii].compare(
+                        other.obj_func[ii], name=name + ".obj_func[" + str(ii) + "]"
+                    )
+                )
+        if other._eval_func_str != self._eval_func_str:
+            diff_list.append(name + ".eval_func")
+        if (other.constraint is None and self.constraint is not None) or (
+            other.constraint is not None and self.constraint is None
+        ):
+            diff_list.append(name + ".constraint None mismatch")
+        elif self.constraint is None:
+            pass
+        elif len(other.constraint) != len(self.constraint):
+            diff_list.append("len(" + name + ".constraint)")
+        else:
+            for ii in range(len(other.constraint)):
+                diff_list.extend(
+                    self.constraint[ii].compare(
+                        other.constraint[ii], name=name + ".constraint[" + str(ii) + "]"
+                    )
+                )
+        if other._preprocessing_str != self._preprocessing_str:
+            diff_list.append(name + ".preprocessing")
+        if (other.datakeeper_list is None and self.datakeeper_list is not None) or (
+            other.datakeeper_list is not None and self.datakeeper_list is None
+        ):
+            diff_list.append(name + ".datakeeper_list None mismatch")
+        elif self.datakeeper_list is None:
+            pass
+        elif len(other.datakeeper_list) != len(self.datakeeper_list):
+            diff_list.append("len(" + name + ".datakeeper_list)")
+        else:
+            for ii in range(len(other.datakeeper_list)):
+                diff_list.extend(
+                    self.datakeeper_list[ii].compare(
+                        other.datakeeper_list[ii],
+                        name=name + ".datakeeper_list[" + str(ii) + "]",
+                    )
+                )
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -195,21 +274,25 @@ class OptiProblem(FrozenClass):
                 S += getsizeof(value)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         OptiProblem_dict = dict()
         if self.simu is None:
             OptiProblem_dict["simu"] = None
         else:
-            OptiProblem_dict["simu"] = self.simu.as_dict()
+            OptiProblem_dict["simu"] = self.simu.as_dict(**kwargs)
         if self.design_var is None:
             OptiProblem_dict["design_var"] = None
         else:
             OptiProblem_dict["design_var"] = list()
             for obj in self.design_var:
                 if obj is not None:
-                    OptiProblem_dict["design_var"].append(obj.as_dict())
+                    OptiProblem_dict["design_var"].append(obj.as_dict(**kwargs))
                 else:
                     OptiProblem_dict["design_var"].append(None)
         if self.obj_func is None:
@@ -218,33 +301,49 @@ class OptiProblem(FrozenClass):
             OptiProblem_dict["obj_func"] = list()
             for obj in self.obj_func:
                 if obj is not None:
-                    OptiProblem_dict["obj_func"].append(obj.as_dict())
+                    OptiProblem_dict["obj_func"].append(obj.as_dict(**kwargs))
                 else:
                     OptiProblem_dict["obj_func"].append(None)
         if self._eval_func_str is not None:
             OptiProblem_dict["eval_func"] = self._eval_func_str
+        elif "keep_function" in kwargs and kwargs["keep_function"]:
+            OptiProblem_dict["eval_func"] = self.eval_func
         else:
             OptiProblem_dict["eval_func"] = None
+            if self.eval_func is not None:
+                self.get_logger().warning(
+                    "OptiProblem.as_dict(): "
+                    + f"Function {self.eval_func.__name__} is not serializable "
+                    + "and will be converted to None."
+                )
         if self.constraint is None:
             OptiProblem_dict["constraint"] = None
         else:
             OptiProblem_dict["constraint"] = list()
             for obj in self.constraint:
                 if obj is not None:
-                    OptiProblem_dict["constraint"].append(obj.as_dict())
+                    OptiProblem_dict["constraint"].append(obj.as_dict(**kwargs))
                 else:
                     OptiProblem_dict["constraint"].append(None)
         if self._preprocessing_str is not None:
             OptiProblem_dict["preprocessing"] = self._preprocessing_str
+        elif "keep_function" in kwargs and kwargs["keep_function"]:
+            OptiProblem_dict["preprocessing"] = self.preprocessing
         else:
             OptiProblem_dict["preprocessing"] = None
+            if self.preprocessing is not None:
+                self.get_logger().warning(
+                    "OptiProblem.as_dict(): "
+                    + f"Function {self.preprocessing.__name__} is not serializable "
+                    + "and will be converted to None."
+                )
         if self.datakeeper_list is None:
             OptiProblem_dict["datakeeper_list"] = None
         else:
             OptiProblem_dict["datakeeper_list"] = list()
             for obj in self.datakeeper_list:
                 if obj is not None:
-                    OptiProblem_dict["datakeeper_list"].append(obj.as_dict())
+                    OptiProblem_dict["datakeeper_list"].append(obj.as_dict(**kwargs))
                 else:
                     OptiProblem_dict["datakeeper_list"].append(None)
         # The class name is added to the dict for deserialisation purpose
@@ -285,7 +384,7 @@ class OptiProblem(FrozenClass):
     simu = property(
         fget=_get_simu,
         fset=_set_simu,
-        doc=u"""Default simulation
+        doc="""Default simulation
 
         :Type: Simulation
         """,
@@ -318,7 +417,7 @@ class OptiProblem(FrozenClass):
     design_var = property(
         fget=_get_design_var,
         fset=_set_design_var,
-        doc=u"""List of design variables
+        doc="""List of design variables
 
         :Type: [OptiDesignVar]
         """,
@@ -351,7 +450,7 @@ class OptiProblem(FrozenClass):
     obj_func = property(
         fget=_get_obj_func,
         fset=_set_obj_func,
-        doc=u"""List of objective functions
+        doc="""List of objective functions
 
         :Type: [OptiObjective]
         """,
@@ -386,7 +485,7 @@ class OptiProblem(FrozenClass):
     eval_func = property(
         fget=_get_eval_func,
         fset=_set_eval_func,
-        doc=u"""Function to evaluate before computing obj function and constraints
+        doc="""Function to evaluate before computing obj function and constraints
 
         :Type: function
         """,
@@ -419,7 +518,7 @@ class OptiProblem(FrozenClass):
     constraint = property(
         fget=_get_constraint,
         fset=_set_constraint,
-        doc=u"""List containing the constraints 
+        doc="""List containing the constraints 
 
         :Type: [OptiConstraint]
         """,
@@ -454,7 +553,7 @@ class OptiProblem(FrozenClass):
     preprocessing = property(
         fget=_get_preprocessing,
         fset=_set_preprocessing,
-        doc=u"""Function to execute a preprocessing on the simulation right before it is run.
+        doc="""Function to execute a preprocessing on the simulation right before it is run.
 
         :Type: function
         """,
@@ -487,7 +586,7 @@ class OptiProblem(FrozenClass):
     datakeeper_list = property(
         fget=_get_datakeeper_list,
         fset=_set_datakeeper_list,
-        doc=u"""List of DataKeepers to run on every output
+        doc="""List of DataKeepers to run on every output
 
         :Type: [DataKeeper]
         """,
