@@ -141,6 +141,19 @@ class ParamExplorerSet(ParamExplorer):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from ParamExplorer
+        diff_list.extend(super(ParamExplorerSet, self).compare(other, name=name))
+        if other._value != self._value:
+            diff_list.append(name + ".value")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
