@@ -226,6 +226,21 @@ class PolarArc(Surface):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from Surface
+        diff_list.extend(super(PolarArc, self).compare(other, name=name))
+        if other._angle != self._angle:
+            diff_list.append(name + ".angle")
+        if other._height != self._height:
+            diff_list.append(name + ".height")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -237,11 +252,15 @@ class PolarArc(Surface):
         S += getsizeof(self.height)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from Surface
-        PolarArc_dict = super(PolarArc, self).as_dict()
+        PolarArc_dict = super(PolarArc, self).as_dict(**kwargs)
         PolarArc_dict["angle"] = self.angle
         PolarArc_dict["height"] = self.height
         # The class name is added to the dict for deserialisation purpose
