@@ -93,6 +93,16 @@ class RefCell(FrozenClass):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+        if other._epsilon != self._epsilon:
+            diff_list.append(name + ".epsilon")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -100,8 +110,12 @@ class RefCell(FrozenClass):
         S += getsizeof(self.epsilon)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         RefCell_dict = dict()
         RefCell_dict["epsilon"] = self.epsilon
