@@ -189,6 +189,17 @@ class RefSegmentP1(RefCell):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from RefCell
+        diff_list.extend(super(RefSegmentP1, self).compare(other, name=name))
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -198,11 +209,15 @@ class RefSegmentP1(RefCell):
         S += super(RefSegmentP1, self).__sizeof__()
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from RefCell
-        RefSegmentP1_dict = super(RefSegmentP1, self).as_dict()
+        RefSegmentP1_dict = super(RefSegmentP1, self).as_dict(**kwargs)
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         RefSegmentP1_dict["__class__"] = "RefSegmentP1"
