@@ -90,6 +90,17 @@ class ScalarProductL2(ScalarProduct):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from ScalarProduct
+        diff_list.extend(super(ScalarProductL2, self).compare(other, name=name))
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -99,11 +110,15 @@ class ScalarProductL2(ScalarProduct):
         S += super(ScalarProductL2, self).__sizeof__()
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from ScalarProduct
-        ScalarProductL2_dict = super(ScalarProductL2, self).as_dict()
+        ScalarProductL2_dict = super(ScalarProductL2, self).as_dict(**kwargs)
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         ScalarProductL2_dict["__class__"] = "ScalarProductL2"
