@@ -271,6 +271,25 @@ class SlotM10(Slot):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from Slot
+        diff_list.extend(super(SlotM10, self).compare(other, name=name))
+        if other._W0 != self._W0:
+            diff_list.append(name + ".W0")
+        if other._H0 != self._H0:
+            diff_list.append(name + ".H0")
+        if other._Wmag != self._Wmag:
+            diff_list.append(name + ".Wmag")
+        if other._Hmag != self._Hmag:
+            diff_list.append(name + ".Hmag")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -284,11 +303,15 @@ class SlotM10(Slot):
         S += getsizeof(self.Hmag)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from Slot
-        SlotM10_dict = super(SlotM10, self).as_dict()
+        SlotM10_dict = super(SlotM10, self).as_dict(**kwargs)
         SlotM10_dict["W0"] = self.W0
         SlotM10_dict["H0"] = self.H0
         SlotM10_dict["Wmag"] = self.Wmag
