@@ -260,6 +260,27 @@ class SlotW16(Slot):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from Slot
+        diff_list.extend(super(SlotW16, self).compare(other, name=name))
+        if other._W0 != self._W0:
+            diff_list.append(name + ".W0")
+        if other._W3 != self._W3:
+            diff_list.append(name + ".W3")
+        if other._H0 != self._H0:
+            diff_list.append(name + ".H0")
+        if other._H2 != self._H2:
+            diff_list.append(name + ".H2")
+        if other._R1 != self._R1:
+            diff_list.append(name + ".R1")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -274,11 +295,15 @@ class SlotW16(Slot):
         S += getsizeof(self.R1)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from Slot
-        SlotW16_dict = super(SlotW16, self).as_dict()
+        SlotW16_dict = super(SlotW16, self).as_dict(**kwargs)
         SlotW16_dict["W0"] = self.W0
         SlotW16_dict["W3"] = self.W3
         SlotW16_dict["H0"] = self.H0
