@@ -287,6 +287,25 @@ class SlotW25(Slot):
             return False
         return True
 
+    def compare(self, other, name="self"):
+        """Compare two objects and return list of differences"""
+
+        if type(other) != type(self):
+            return ["type(" + name + ")"]
+        diff_list = list()
+
+        # Check the properties inherited from Slot
+        diff_list.extend(super(SlotW25, self).compare(other, name=name))
+        if other._W3 != self._W3:
+            diff_list.append(name + ".W3")
+        if other._H2 != self._H2:
+            diff_list.append(name + ".H2")
+        if other._W4 != self._W4:
+            diff_list.append(name + ".W4")
+        if other._H1 != self._H1:
+            diff_list.append(name + ".H1")
+        return diff_list
+
     def __sizeof__(self):
         """Return the size in memory of the object (including all subobject)"""
 
@@ -300,11 +319,15 @@ class SlotW25(Slot):
         S += getsizeof(self.H1)
         return S
 
-    def as_dict(self):
-        """Convert this object in a json seriable dict (can be use in __init__)"""
+    def as_dict(self, **kwargs):
+        """
+        Convert this object in a json serializable dict (can be use in __init__).
+        Optional keyword input parameter is for internal use only
+        and may prevent json serializability.
+        """
 
         # Get the properties inherited from Slot
-        SlotW25_dict = super(SlotW25, self).as_dict()
+        SlotW25_dict = super(SlotW25, self).as_dict(**kwargs)
         SlotW25_dict["W3"] = self.W3
         SlotW25_dict["H2"] = self.H2
         SlotW25_dict["W4"] = self.W4
