@@ -8,7 +8,7 @@ from PySide2.QtWidgets import QWidget
 from ......Classes.SlotW22 import SlotW22
 from ......GUI import gui_option
 from ......GUI.Dialog.DMachineSetup.SWSlot.PWSlot22.Gen_PWSlot22 import Gen_PWSlot22
-from ......Methods.Slot.Slot.check import SlotCheckError
+from ......Methods.Slot.Slot import SlotCheckError
 
 translate = PySide2.QtCore.QCoreApplication.translate
 
@@ -44,7 +44,7 @@ class PWSlot22(Gen_PWSlot22, QWidget):
         # Set unit name (m ou mm)
         wid_list = [self.unit_H0, self.unit_H2]
         for wid in wid_list:
-            wid.setText(gui_option.unit.get_m_name())
+            wid.setText("[" + gui_option.unit.get_m_name() + "]")
 
         # Fill the fields with the machine values (if they're filled)
         self.lf_W0.setValue(self.slot.W0)
@@ -171,15 +171,15 @@ class PWSlot22(Gen_PWSlot22, QWidget):
 
         # Check that everything is set
         if lam.slot.Zs is None:
-            return translate("You must set Zs !", "PWSlot22 check")
+            return "You must set Zs !"
         elif lam.slot.W0 is None:
-            return translate("You must set W0 !", "PWSlot22 check")
+            return "You must set W0 !"
         elif lam.slot.W2 is None:
-            return translate("You must set W2 !", "PWSlot22 check")
+            return "You must set W2 !"
         elif lam.slot.H0 is None:
-            return translate("You must set H0 !", "PWSlot22 check")
+            return "You must set H0 !"
         elif lam.slot.H2 is None:
-            return translate("You must set H2 !", "PWSlot22 check")
+            return "You must set H2 !"
 
         # Check that everything is set right
         # Constraints
@@ -192,10 +192,6 @@ class PWSlot22(Gen_PWSlot22, QWidget):
         try:
             yoke_height = lam.comp_height_yoke()
         except Exception as error:
-            return translate("Unable to compute yoke height:", "PWSlot22 check") + str(
-                error
-            )
+            return "Unable to compute yoke height:" + str(error)
         if yoke_height <= 0:
-            return translate(
-                "The slot height is greater than the lamination !", "PWSlot22 check"
-            )
+            return "The slot height is greater than the lamination !"
