@@ -19,7 +19,7 @@ class Ui_PWSlot23(object):
     def setupUi(self, PWSlot23):
         if not PWSlot23.objectName():
             PWSlot23.setObjectName(u"PWSlot23")
-        PWSlot23.resize(630, 470)
+        PWSlot23.resize(848, 470)
         PWSlot23.setMinimumSize(QSize(630, 470))
         PWSlot23.setMaximumSize(QSize(16777215, 16777215))
         self.horizontalLayout = QHBoxLayout(PWSlot23)
@@ -35,7 +35,7 @@ class Ui_PWSlot23(object):
         self.img_slot.setSizePolicy(sizePolicy)
         self.img_slot.setMaximumSize(QSize(16777215, 16777215))
         self.img_slot.setPixmap(
-            QPixmap(u":/images/images/MachineSetup/WSlot/Slot 23.PNG")
+            QPixmap(u":/images/images/MachineSetup/WSlot/SlotW23.png")
         )
         self.img_slot.setScaledContents(True)
 
@@ -50,7 +50,7 @@ class Ui_PWSlot23(object):
             self.txt_constraint.sizePolicy().hasHeightForWidth()
         )
         self.txt_constraint.setSizePolicy(sizePolicy1)
-        self.txt_constraint.setMaximumSize(QSize(16777215, 50))
+        self.txt_constraint.setMaximumSize(QSize(16777215, 70))
         self.txt_constraint.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         self.txt_constraint.setTextInteractionFlags(
             Qt.TextSelectableByKeyboard | Qt.TextSelectableByMouse
@@ -60,128 +60,138 @@ class Ui_PWSlot23(object):
 
         self.horizontalLayout.addLayout(self.verticalLayout_2)
 
-        self.verticalLayout = QVBoxLayout()
+        self.widget = QWidget(PWSlot23)
+        self.widget.setObjectName(u"widget")
+        self.widget.setMinimumSize(QSize(250, 0))
+        self.widget.setMaximumSize(QSize(250, 16777215))
+        self.verticalLayout = QVBoxLayout(self.widget)
         self.verticalLayout.setObjectName(u"verticalLayout")
-        self.is_cst_tooth = QCheckBox(PWSlot23)
+        self.is_cst_tooth = QCheckBox(self.widget)
         self.is_cst_tooth.setObjectName(u"is_cst_tooth")
 
         self.verticalLayout.addWidget(self.is_cst_tooth)
 
         self.gridLayout = QGridLayout()
         self.gridLayout.setObjectName(u"gridLayout")
-        self.in_W0 = QLabel(PWSlot23)
+        self.in_W0 = QLabel(self.widget)
         self.in_W0.setObjectName(u"in_W0")
 
         self.gridLayout.addWidget(self.in_W0, 0, 0, 1, 1)
 
-        self.lf_W0 = FloatEdit(PWSlot23)
+        self.lf_W0 = FloatEdit(self.widget)
         self.lf_W0.setObjectName(u"lf_W0")
 
         self.gridLayout.addWidget(self.lf_W0, 0, 1, 1, 1)
 
-        self.unit_W0 = QLabel(PWSlot23)
+        self.unit_W0 = QLabel(self.widget)
         self.unit_W0.setObjectName(u"unit_W0")
 
         self.gridLayout.addWidget(self.unit_W0, 0, 2, 1, 1)
 
-        self.in_W1 = QLabel(PWSlot23)
+        self.in_W1 = QLabel(self.widget)
         self.in_W1.setObjectName(u"in_W1")
 
         self.gridLayout.addWidget(self.in_W1, 1, 0, 1, 1)
 
-        self.lf_W1 = FloatEdit(PWSlot23)
+        self.lf_W1 = FloatEdit(self.widget)
         self.lf_W1.setObjectName(u"lf_W1")
 
         self.gridLayout.addWidget(self.lf_W1, 1, 1, 1, 1)
 
-        self.unit_W1 = QLabel(PWSlot23)
+        self.unit_W1 = QLabel(self.widget)
         self.unit_W1.setObjectName(u"unit_W1")
 
         self.gridLayout.addWidget(self.unit_W1, 1, 2, 1, 1)
 
-        self.in_W2 = QLabel(PWSlot23)
+        self.in_W2 = QLabel(self.widget)
         self.in_W2.setObjectName(u"in_W2")
 
         self.gridLayout.addWidget(self.in_W2, 2, 0, 1, 1)
 
-        self.lf_W2 = FloatEdit(PWSlot23)
+        self.lf_W2 = FloatEdit(self.widget)
         self.lf_W2.setObjectName(u"lf_W2")
 
         self.gridLayout.addWidget(self.lf_W2, 2, 1, 1, 1)
 
-        self.unit_W2 = QLabel(PWSlot23)
+        self.unit_W2 = QLabel(self.widget)
         self.unit_W2.setObjectName(u"unit_W2")
 
         self.gridLayout.addWidget(self.unit_W2, 2, 2, 1, 1)
 
-        self.in_W3 = QLabel(PWSlot23)
+        self.in_W3 = QLabel(self.widget)
         self.in_W3.setObjectName(u"in_W3")
 
         self.gridLayout.addWidget(self.in_W3, 3, 0, 1, 1)
 
-        self.lf_W3 = FloatEdit(PWSlot23)
+        self.lf_W3 = FloatEdit(self.widget)
         self.lf_W3.setObjectName(u"lf_W3")
 
         self.gridLayout.addWidget(self.lf_W3, 3, 1, 1, 1)
 
-        self.unit_W3 = QLabel(PWSlot23)
+        self.unit_W3 = QLabel(self.widget)
         self.unit_W3.setObjectName(u"unit_W3")
 
         self.gridLayout.addWidget(self.unit_W3, 3, 2, 1, 1)
 
-        self.in_H0 = QLabel(PWSlot23)
+        self.in_H0 = QLabel(self.widget)
         self.in_H0.setObjectName(u"in_H0")
 
         self.gridLayout.addWidget(self.in_H0, 4, 0, 1, 1)
 
-        self.lf_H0 = FloatEdit(PWSlot23)
+        self.lf_H0 = FloatEdit(self.widget)
         self.lf_H0.setObjectName(u"lf_H0")
 
         self.gridLayout.addWidget(self.lf_H0, 4, 1, 1, 1)
 
-        self.unit_H0 = QLabel(PWSlot23)
+        self.unit_H0 = QLabel(self.widget)
         self.unit_H0.setObjectName(u"unit_H0")
 
         self.gridLayout.addWidget(self.unit_H0, 4, 2, 1, 1)
 
-        self.in_H1 = QLabel(PWSlot23)
+        self.in_H1 = QLabel(self.widget)
         self.in_H1.setObjectName(u"in_H1")
 
         self.gridLayout.addWidget(self.in_H1, 5, 0, 1, 1)
 
-        self.lf_H1 = FloatEdit(PWSlot23)
+        self.lf_H1 = FloatEdit(self.widget)
         self.lf_H1.setObjectName(u"lf_H1")
 
         self.gridLayout.addWidget(self.lf_H1, 5, 1, 1, 1)
 
-        self.in_H2 = QLabel(PWSlot23)
+        self.in_H2 = QLabel(self.widget)
         self.in_H2.setObjectName(u"in_H2")
 
         self.gridLayout.addWidget(self.in_H2, 6, 0, 1, 1)
 
-        self.lf_H2 = FloatEdit(PWSlot23)
+        self.lf_H2 = FloatEdit(self.widget)
         self.lf_H2.setObjectName(u"lf_H2")
 
         self.gridLayout.addWidget(self.lf_H2, 6, 1, 1, 1)
 
-        self.unit_H2 = QLabel(PWSlot23)
+        self.unit_H2 = QLabel(self.widget)
         self.unit_H2.setObjectName(u"unit_H2")
 
         self.gridLayout.addWidget(self.unit_H2, 6, 2, 1, 1)
 
-        self.unit_H1 = QLabel(PWSlot23)
+        self.unit_H1 = QLabel(self.widget)
         self.unit_H1.setObjectName(u"unit_H1")
 
         self.gridLayout.addWidget(self.unit_H1, 5, 2, 1, 1)
 
         self.verticalLayout.addLayout(self.gridLayout)
 
-        self.w_out = WWSlotOut(PWSlot23)
+        self.verticalSpacer = QSpacerItem(
+            20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding
+        )
+
+        self.verticalLayout.addItem(self.verticalSpacer)
+
+        self.w_out = WWSlotOut(self.widget)
         self.w_out.setObjectName(u"w_out")
 
         self.verticalLayout.addWidget(self.w_out)
 
-        self.horizontalLayout.addLayout(self.verticalLayout)
+        self.horizontalLayout.addWidget(self.widget)
 
         QWidget.setTabOrder(self.is_cst_tooth, self.lf_W0)
         QWidget.setTabOrder(self.lf_W0, self.lf_W1)
@@ -216,18 +226,18 @@ class Ui_PWSlot23(object):
         self.is_cst_tooth.setText(
             QCoreApplication.translate("PWSlot23", u"Constant Tooth Width", None)
         )
-        self.in_W0.setText(QCoreApplication.translate("PWSlot23", u"W0 :", None))
+        self.in_W0.setText(QCoreApplication.translate("PWSlot23", u"W0", None))
         self.unit_W0.setText(QCoreApplication.translate("PWSlot23", u"m", None))
-        self.in_W1.setText(QCoreApplication.translate("PWSlot23", u"W1 :", None))
+        self.in_W1.setText(QCoreApplication.translate("PWSlot23", u"W1", None))
         self.unit_W1.setText(QCoreApplication.translate("PWSlot23", u"m", None))
-        self.in_W2.setText(QCoreApplication.translate("PWSlot23", u"W2 :", None))
+        self.in_W2.setText(QCoreApplication.translate("PWSlot23", u"W2", None))
         self.unit_W2.setText(QCoreApplication.translate("PWSlot23", u"m", None))
-        self.in_W3.setText(QCoreApplication.translate("PWSlot23", u"W3 :", None))
+        self.in_W3.setText(QCoreApplication.translate("PWSlot23", u"W3", None))
         self.unit_W3.setText(QCoreApplication.translate("PWSlot23", u"m", None))
-        self.in_H0.setText(QCoreApplication.translate("PWSlot23", u"H0 :", None))
+        self.in_H0.setText(QCoreApplication.translate("PWSlot23", u"H0", None))
         self.unit_H0.setText(QCoreApplication.translate("PWSlot23", u"m", None))
-        self.in_H1.setText(QCoreApplication.translate("PWSlot23", u"H1 :", None))
-        self.in_H2.setText(QCoreApplication.translate("PWSlot23", u"H2 :", None))
+        self.in_H1.setText(QCoreApplication.translate("PWSlot23", u"H1", None))
+        self.in_H2.setText(QCoreApplication.translate("PWSlot23", u"H2", None))
         self.unit_H2.setText(QCoreApplication.translate("PWSlot23", u"m", None))
         self.unit_H1.setText(QCoreApplication.translate("PWSlot23", u"m", None))
 
