@@ -1,23 +1,22 @@
 # -*- coding: utf-8 -*-
 
-import PyQt5.QtCore
-from PyQt5.QtCore import pyqtSignal
-from PyQt5.QtWidgets import QWidget
+import PySide2.QtCore
+from PySide2.QtCore import Signal
+from PySide2.QtWidgets import QWidget
 
 from ......Classes.SlotW26 import SlotW26
 from ......GUI import gui_option
 from ......GUI.Dialog.DMachineSetup.SWSlot.PWSlot26.Gen_PWSlot26 import Gen_PWSlot26
-from ......Methods.Slot.Slot.check import SlotCheckError
+from ......Methods.Slot.Slot import SlotCheckError
 
-translate = PyQt5.QtCore.QCoreApplication.translate
+translate = PySide2.QtCore.QCoreApplication.translate
 
 
 class PWSlot26(Gen_PWSlot26, QWidget):
-    """Page to set the Slot Type 26
-    """
+    """Page to set the Slot Type 26"""
 
     # Signal to DMachineSetup to know that the save popup is needed
-    saveNeeded = pyqtSignal()
+    saveNeeded = Signal()
     # Information for Slot combobox
     slot_name = "Slot Type 26"
     slot_type = SlotW26
@@ -54,7 +53,7 @@ class PWSlot26(Gen_PWSlot26, QWidget):
             self.unit_R2,
         ]
         for wid in wid_list:
-            wid.setText(gui_option.unit.get_m_name())
+            wid.setText("[" + gui_option.unit.get_m_name() + "]")
         # Fill the fields with the machine values (if they're filled)
         self.lf_W0.setValue(self.slot.W0)
         self.lf_H0.setValue(self.slot.H0)
@@ -154,15 +153,15 @@ class PWSlot26(Gen_PWSlot26, QWidget):
 
         # Check that everything is set
         if lam.slot.W0 is None:
-            return translate("You must set W0 !", "PWSlot26 check")
+            return "You must set W0 !"
         elif lam.slot.H0 is None:
-            return translate("You must set H0 !", "PWSlot26 check")
+            return "You must set H0 !"
         elif lam.slot.H1 is None:
-            return translate("You must set H1 !", "PWSlot26 check")
+            return "You must set H1 !"
         elif lam.slot.R1 is None:
-            return translate("You must set R1 !", "PWSlot26 check")
+            return "You must set R1 !"
         elif lam.slot.R2 is None:
-            return translate("You must set R2 !", "PWSlot26 check")
+            return "You must set R2 !"
         # Check that everything is set right
         # Constraints
         try:
@@ -174,10 +173,6 @@ class PWSlot26(Gen_PWSlot26, QWidget):
         try:
             yoke_height = lam.comp_height_yoke()
         except Exception as error:
-            return translate("Unable to compute yoke height:", "PWSlot26 check") + str(
-                error
-            )
+            return "Unable to compute yoke height:" + str(error)
         if yoke_height <= 0:
-            return translate(
-                "The slot height is greater than the lamination !", "PWSlot26 check"
-            )
+            return "The slot height is greater than the lamination !"
