@@ -53,7 +53,12 @@ def get_field(
 
     # Get field
     solution = self.get_solution(label=label, index=index)
-    field = solution.get_field(args=args)
+
+    if args is not None:
+        field = solution.get_field(args)
+    else:
+        field = solution.get_field()
+
     field = squeeze(field)
 
     # Check dimensions
@@ -88,7 +93,7 @@ def get_field(
             mesh = MeshVTK(mesh=mesh_pv, is_pyvista_mesh=True)
     # Get points coordinates if necessary
     if is_rthetaz:
-        points = mesh.get_points(indices=indices)
+        points = mesh.get_point(indices=indices)
     # Get normals if necessary
     if is_normal and is_center:
         # Get normals
