@@ -31,8 +31,8 @@ def get_mesh(self, label=None, index=None):
         if index is None:
             index = 0
             if label is not None:
-                for i, solution in enumerate(self.solution):
-                    if solution.label == label:
+                for i, mesh in enumerate(self.mesh):
+                    if mesh.label == label:
                         index = i
         tmpmesh = self.mesh[index]
 
