@@ -2,7 +2,6 @@
 
 
 class InputError(Exception):
-    """Raised when the input data are incomplete or incorrect
-    """
+    """Raised when the input data are incomplete or incorrect"""
 
     pass
