@@ -21,7 +21,7 @@ def comp_surface(self):
 
     Rbo = self.get_Rbo()
 
-    Swind = self.comp_surface_wind()
+    Swind = self.comp_surface_active()
 
     # The bottom is an arc
     alpha = self.comp_angle_opening()
